API Reference
=============

.. autoclass:: resfo_utilities.CornerpointGrid
   :members:

.. autoexception:: resfo_utilities.InvalidEgridFileError
.. autoexception:: resfo_utilities.InvalidGridError

.. autoclass:: resfo_utilities.MapAxes
   :members:

.. autoclass:: resfo_utilities.SummaryReader
   :members:

.. autoexception:: resfo_utilities.InvalidSummaryError

.. autoclass:: resfo_utilities.SummaryKeyword
   :members:

.. autofunction:: resfo_utilities.make_summary_key

.. autoexception:: resfo_utilities.InvalidSummaryKeyError

.. autoclass:: resfo_utilities.SummaryKeyType
   :members:

.. autofunction:: resfo_utilities.is_rate

.. autofunction:: resfo_utilities.history_key

.. autoclass:: resfo_utilities.RFTEntry
   :members:

.. autoclass:: resfo_utilities.RFTReader
   :members:

.. autoclass:: resfo_utilities.RFTDataCategory
   :members:

.. autoclass:: resfo_utilities.TypeOfWell
   :members:

.. autoexception:: resfo_utilities.InvalidRFTError

Testing
-------
.. automodule:: resfo_utilities.testing
   :members:
